==> openshift-model-installer-5.12.4-sources.jar: io/fabric8/openshift/api/model/installer/ovirt/v1/PlatformBuilder.java <==
package io.fabric8.openshift.api.model.installer.ovirt.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class PlatformBuilder extends io.fabric8.openshift.api.model.installer.ovirt.v1.PlatformFluentImpl<io.fabric8.openshift.api.model.installer.ovirt.v1.PlatformBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.installer.ovirt.v1.Platform,io.fabric8.openshift.api.model.installer.ovirt.v1.PlatformBuilder>{
  public PlatformBuilder() {
    this(false);
  }
  public PlatformBuilder(java.lang.Boolean validationEnabled) {
    this(new Platform(), validationEnabled);
  }
  public PlatformBuilder(io.fabric8.openshift.api.model.installer.ovirt.v1.PlatformFluent<?> fluent) {
    this(fluent, false);
  }
  public PlatformBuilder(io.fabric8.openshift.api.model.installer.ovirt.v1.PlatformFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new Platform(), validationEnabled);
  }
  public PlatformBuilder(io.fabric8.openshift.api.model.installer.ovirt.v1.PlatformFluent<?> fluent,io.fabric8.openshift.api.model.installer.ovirt.v1.Platform instance) {
    this(fluent, instance, false);
  }
  public PlatformBuilder(io.fabric8.openshift.api.model.installer.ovirt.v1.PlatformFluent<?> fluent,io.fabric8.openshift.api.model.installer.ovirt.v1.Platform instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAffinityGroups(instance.getAffinityGroups()); 
    fluent.withApiVip(instance.getApiVip()); 
    fluent.withDefaultMachinePlatform(instance.getDefaultMachinePlatform()); 
    fluent.withIngressVip(instance.getIngressVip()); 
    fluent.withOvirtClusterId(instance.getOvirtClusterId()); 
    fluent.withOvirtNetworkName(instance.getOvirtNetworkName()); 
    fluent.withOvirtStorageDomainId(instance.getOvirtStorageDomainId()); 
    fluent.withVnicProfileID(instance.getVnicProfileID()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public PlatformBuilder(io.fabric8.openshift.api.model.installer.ovirt.v1.Platform instance) {
    this(instance,false);
  }
  public PlatformBuilder(io.fabric8.openshift.api.model.installer.ovirt.v1.Platform instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAffinityGroups(instance.getAffinityGroups()); 
    this.withApiVip(instance.getApiVip()); 
    this.withDefaultMachinePlatform(instance.getDefaultMachinePlatform()); 
    this.withIngressVip(instance.getIngressVip()); 
    this.withOvirtClusterId(instance.getOvirtClusterId()); 
    this.withOvirtNetworkName(instance.getOvirtNetworkName()); 
    this.withOvirtStorageDomainId(instance.getOvirtStorageDomainId()); 
    this.withVnicProfileID(instance.getVnicProfileID()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.installer.ovirt.v1.PlatformFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.installer.ovirt.v1.Platform build() {
    Platform buildable = new Platform(fluent.getAffinityGroups(),fluent.getApiVip(),fluent.getDefaultMachinePlatform(),fluent.getIngressVip(),fluent.getOvirtClusterId(),fluent.getOvirtNetworkName(),fluent.getOvirtStorageDomainId(),fluent.getVnicProfileID());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PlatformBuilder that = (PlatformBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-installer-6.5.1-sources.jar: io/fabric8/openshift/api/model/installer/ovirt/v1/PlatformBuilder.java <==
package io.fabric8.openshift.api.model.installer.ovirt.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class PlatformBuilder extends PlatformFluentImpl<PlatformBuilder> implements VisitableBuilder<Platform,PlatformBuilder>{
  public PlatformBuilder() {
    this(false);
  }
  public PlatformBuilder(Boolean validationEnabled) {
    this(new Platform(), validationEnabled);
  }
  public PlatformBuilder(PlatformFluent<?> fluent) {
    this(fluent, false);
  }
  public PlatformBuilder(PlatformFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new Platform(), validationEnabled);
  }
  public PlatformBuilder(PlatformFluent<?> fluent,Platform instance) {
    this(fluent, instance, false);
  }
  public PlatformBuilder(PlatformFluent<?> fluent,Platform instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAffinityGroups(instance.getAffinityGroups()); 
    fluent.withApiVip(instance.getApiVip()); 
    fluent.withDefaultMachinePlatform(instance.getDefaultMachinePlatform()); 
    fluent.withIngressVip(instance.getIngressVip()); 
    fluent.withOvirtClusterId(instance.getOvirtClusterId()); 
    fluent.withOvirtNetworkName(instance.getOvirtNetworkName()); 
    fluent.withOvirtStorageDomainId(instance.getOvirtStorageDomainId()); 
    fluent.withVnicProfileID(instance.getVnicProfileID()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public PlatformBuilder(Platform instance) {
    this(instance,false);
  }
  public PlatformBuilder(Platform instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withAffinityGroups(instance.getAffinityGroups()); 
    this.withApiVip(instance.getApiVip()); 
    this.withDefaultMachinePlatform(instance.getDefaultMachinePlatform()); 
    this.withIngressVip(instance.getIngressVip()); 
    this.withOvirtClusterId(instance.getOvirtClusterId()); 
    this.withOvirtNetworkName(instance.getOvirtNetworkName()); 
    this.withOvirtStorageDomainId(instance.getOvirtStorageDomainId()); 
    this.withVnicProfileID(instance.getVnicProfileID()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  PlatformFluent<?> fluent;
  Boolean validationEnabled;
  public Platform build() {
    Platform buildable = new Platform(fluent.getAffinityGroups(),fluent.getApiVip(),fluent.getDefaultMachinePlatform(),fluent.getIngressVip(),fluent.getOvirtClusterId(),fluent.getOvirtNetworkName(),fluent.getOvirtStorageDomainId(),fluent.getVnicProfileID());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
